# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

certificate_help = """For a detailed explanation of CA certificates in Azure IoT Hub,
                      see https://docs.microsoft.com/en-us/azure/iot-hub/iot-hub-x509ca-overview """
