# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# pylint: skip-file
# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 0.17.0.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Authentication(Model):
    """Authentication information.

    :param symmetric_key:
    :type symmetric_key: :class:`SymmetricKey
     <iothubdeviceclient.models.SymmetricKey>`
    :param x509_thumbprint:
    :type x509_thumbprint: :class:`X509Thumbprint
     <iothubdeviceclient.models.X509Thumbprint>`
    """

    _attribute_map = {
        'symmetric_key': {'key': 'symmetricKey', 'type': 'SymmetricKey'},
        'x509_thumbprint': {'key': 'x509Thumbprint', 'type': 'X509Thumbprint'},
    }

    def __init__(self, symmetric_key=None, x509_thumbprint=None):
        self.symmetric_key = symmetric_key
        self.x509_thumbprint = x509_thumbprint
